@@ -93,15 +93,13 @@ predict_party.simpleparty <- function(party, id, newdata = NULL,
 
   ## predictions
   if(type == "response") {
-    .simplify_pred(nodeapply(party, nodeids(party),
-      function(x) x$info$prediction, by_node = TRUE), id, nam)
+    FUN <- function(x) x$info$prediction
   } else {
     if(is.null(node_party(party)$info$distribution)) stop("probabilities not available")
     scale <- any(node_party(party)$info$distribution > 1)
-    .simplify_pred(nodeapply(party, nodeids(party),
-      function(x) if(scale) prop.table(x$info$distribution) else x$info$distribution,
-      by_node = TRUE), id, nam)
+    FUN <- function(x) if(scale) prop.table(x$info$distribution) else x$info$distribution
   }
+  predict_party.default(party, id, nam, FUN = FUN, ...)
 }
 
 as.simpleparty <- function(obj, ...) UseMethod("as.simpleparty")
@@ -109,11 +107,13 @@ as.simpleparty <- function(obj, ...) UseMethod("as.simpleparty")
 as.simpleparty.simpleparty <- function(obj, ...) obj
 
 as.simpleparty.party <- function(obj, ...) {
-  if (is.simpleparty(obj)) 
+  if (is.simpleparty(obj)) {
+      class(obj) <- unique(c("simpleparty", class(obj)))
       return(obj)
+  }
   if (is.constparty(obj)) 
       return(as.simpleparty(as.constparty(obj)))
-  stop("can't coerse objects of class ", sQuote(class(obj)), 
+  stop("cannot coerce objects of class ", sQuote(class(obj)), 
        " to class ", sQuote("simpleparty"))
 }
 
@@ -133,6 +133,11 @@ as.simpleparty.constparty <- function(obj, ...) {
   FUN <- function(node, fitted) {
     fitted <- subset(fitted,
       fitted[["(fitted)"]] %in% nodeids(node, terminal = TRUE))
+
+    if (nrow(fitted) == 0)
+      return(list(prediction = NA, n = 0,
+                  error = NA, distribution = NULL))
+
     y <- fitted[["(response)"]]
     w <- fitted[["(weights)"]]
     if(is.null(w)) {
@@ -144,7 +149,7 @@ as.simpleparty.constparty <- function(obj, ...) {
     
     switch(rtype,
       "numeric" = {
-        yhat <- .pred_numeric(y, w)
+        yhat <- .pred_numeric_response(y, w)
         list(prediction = yhat, n = structure(sum(w), .Names = wnam),
 	  error = sum(w * (y - yhat)^2), distribution = NULL)
       },
@@ -167,7 +172,8 @@ as.simpleparty.constparty <- function(obj, ...) {
     nlevels <- levels(fit)
     for(i in 1:length(idlist)) nlevels[match(idlist[[i]], levels(fit))] <- i
     levels(fit) <- nlevels
-    as.numeric(factor(fit))
+    ret <- factor(as.numeric(as.character(fit)), labels = 1:length(idlist), levels = 1:length(idlist))
+    ret
   }
 
   ## cycle through node
@@ -177,7 +183,7 @@ as.simpleparty.constparty <- function(obj, ...) {
       info = FUN(onode, fitted)))
     kids <- kids_node(onode)
     kids_tid <- lapply(kids, nodeids, terminal = TRUE)
-    kids_fitted <- base::split.data.frame(fitted, fit2id(fitted[["(fitted)"]], kids_tid))
+    kids_fitted <- base::split.data.frame(fitted, fit2id(fitted[["(fitted)"]], kids_tid), drop = FALSE)
     partynode(id = onode$id, split = onode$split,
       kids = lapply(1:length(kids), function(i) new_node(kids[[i]], kids_fitted[[i]])),
       surrogates = onode$surrogates,
